==> financial-settlement-service-0.1.273-sources.jar: com/xforceplus/ultraman/app/financialsettlement/controller/ChargeCodeController.java <==
package com.xforceplus.ultraman.app.financialsettlement.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.financialsettlement.entity.ChargeCode;
import com.xforceplus.ultraman.app.financialsettlement.service.IChargeCodeService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * 成本编码基础表前端控制器
 *
 * @author ultraman
 * @date 2022-09-29
 */
@RestController
public class ChargeCodeController {

  @Autowired
  private IChargeCodeService chargeCodeServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param chargeCode 成本编码基础表
   * @return
   */
  @GetMapping("/chargecodes" )
  public XfR getChargeCodes(XfPage page, ChargeCode chargeCode) {
    return XfR.ok(chargeCodeServiceImpl.page(page, Wrappers.query(chargeCode)));
  }

  /**
   * 通过id查询成本编码基础表
   * @param  id
   * @return XfR
   */
  @GetMapping("/chargecodes/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(chargeCodeServiceImpl.getById(id));
  }

  /**
   * 新增成本编码基础表
   * @param chargeCode 成本编码基础表
   * @return XfR
   */
  @PostMapping("/chargecodes")
  public XfR save(@RequestBody ChargeCode chargeCode) {
     return XfR.ok(chargeCodeServiceImpl.save(chargeCode));
  }

  /**
   * 修改-传入修改后的全部数据成本编码基础表
   * @param chargeCode 成本编码基础表
   * @return XfR
   */
  @PutMapping("/chargecodes/{id}")
  public XfR putUpdate(@RequestBody ChargeCode chargeCode,@PathVariable Long id) {
      chargeCode.setId(id);
      return XfR.ok(chargeCodeServiceImpl.updateById(chargeCode));
  }

  /**
   * 修改-传入修改的数据成本编码基础表
   * @param chargeCode 成本编码基础表
   * @return XfR
   */
  @PatchMapping("/chargecodes/{id}")
  public XfR patchUpdate(@RequestBody ChargeCode chargeCode,@PathVariable Long id) {
      ChargeCode upchargeCode = chargeCodeServiceImpl.getById(id);
      if(upchargeCode != null){
        upchargeCode = ObjectCopyUtils.copyProperties(chargeCode,upchargeCode,true);
      }
      return XfR.ok(chargeCodeServiceImpl.updateById(upchargeCode));
  }

  /**
   * 通过id删除成本编码基础表
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/chargecodes/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(chargeCodeServiceImpl.removeById(id));
  }

  @PostMapping("/chargecodes/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "charge_code");
     params.put("request", condition);

     return XfR.ok(chargeCodeServiceImpl.querys(params));
  }

}

==> financial-settlement-service-0.1.318-sources.jar: com/xforceplus/ultraman/app/financialsettlement/controller/ChargeCodeController.java <==
package com.xforceplus.ultraman.app.financialsettlement.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.financialsettlement.entity.ChargeCode;
import com.xforceplus.ultraman.app.financialsettlement.service.IChargeCodeService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * 成本编码基础表前端控制器
 *
 * @author ultraman
 * @date 2023-03-08
 */
@RestController
public class ChargeCodeController {

  @Autowired
  private IChargeCodeService chargeCodeServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param chargeCode 成本编码基础表
   * @return
   */
  @GetMapping("/chargecodes" )
  public XfR getChargeCodes(XfPage page, ChargeCode chargeCode) {
    return XfR.ok(chargeCodeServiceImpl.page(page, Wrappers.query(chargeCode)));
  }

  /**
   * 通过id查询成本编码基础表
   * @param  id
   * @return XfR
   */
  @GetMapping("/chargecodes/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(chargeCodeServiceImpl.getById(id));
  }

  /**
   * 新增成本编码基础表
   * @param chargeCode 成本编码基础表
   * @return XfR
   */
  @PostMapping("/chargecodes")
  public XfR save(@RequestBody ChargeCode chargeCode) {
     return XfR.ok(chargeCodeServiceImpl.save(chargeCode));
  }

  /**
   * 修改-传入修改后的全部数据成本编码基础表
   * @param chargeCode 成本编码基础表
   * @return XfR
   */
  @PutMapping("/chargecodes/{id}")
  public XfR putUpdate(@RequestBody ChargeCode chargeCode,@PathVariable Long id) {
      chargeCode.setId(id);
      return XfR.ok(chargeCodeServiceImpl.updateById(chargeCode));
  }

  /**
   * 修改-传入修改的数据成本编码基础表
   * @param chargeCode 成本编码基础表
   * @return XfR
   */
  @PatchMapping("/chargecodes/{id}")
  public XfR patchUpdate(@RequestBody ChargeCode chargeCode,@PathVariable Long id) {
      ChargeCode upchargeCode = chargeCodeServiceImpl.getById(id);
      if(upchargeCode != null){
        upchargeCode = ObjectCopyUtils.copyProperties(chargeCode,upchargeCode,true);
      }
      return XfR.ok(chargeCodeServiceImpl.updateById(upchargeCode));
  }

  /**
   * 通过id删除成本编码基础表
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/chargecodes/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(chargeCodeServiceImpl.removeById(id));
  }

  @PostMapping("/chargecodes/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "charge_code");
     params.put("request", condition);

     return XfR.ok(chargeCodeServiceImpl.querys(params));
  }

}
